@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
-from ..utils import Markup, get_html_attrs, to_unicode
+from .._compat import to_unicode
+from ..utils import Markup, get_html_attrs
 from .field import Field
 
 
@@ -7,10 +8,11 @@ TMPL = u'<label><input {attrs}> {label}</label>'
 
 
 class Select(Field):
+
     """A field with a fixed list of options for the possible values
 
     :param items:
-        Either: 
+        Either:
         - An list of tuples with the format `(value, label)`; or
         - A function that return a list of items in that format.
 
@@ -35,9 +37,10 @@ class Select(Field):
         fields.
 
     """
-    
-    def __init__(self, items, **kwargs):
+
+    def __init__(self, items, type=None, **kwargs):
         self._items = items
+        self.type = type
         super(Select, self).__init__(**kwargs)
 
     @property
@@ -53,9 +56,17 @@ class Select(Field):
     def str_to_py(self, **kwargs):
         accepted = [str(item[0]) for item in self]
         if self.str_value in accepted:
-            return self.str_value
+            return self._clean_value(self.str_value)
         return None
 
+    def _clean_value(self, value):
+        if not self.type:
+            return value
+        try:
+            return self.type(value)
+        except (ValueError, TypeError):
+            return None
+
     def __call__(self, **kwargs):
         items = self.items
         if len(items) > 5:
@@ -64,11 +75,11 @@ class Select(Field):
 
     def as_select(self, _items=None, **kwargs):
         """Render the field as a `<select>` element.
-        
+
         :param **kwargs:
             Named paremeters used to generate the HTML attributes of each item.
             It follows the same rules as `get_html_attrs`
-        
+
         """
         kwargs['name'] = self.name
         if not self.optional:
@@ -89,36 +100,42 @@ class Select(Field):
     def as_radios(self, tmpl=TMPL, _items=None, **kwargs):
         """Render the field as a series of radio buttons, using the `tmpl`
         parameter as the template for each item.
-        
+
         :param tmpl:
             HTML template to use for rendering each item.
 
         :param **kwargs:
             Named paremeters used to generate the HTML attributes of each item.
             It follows the same rules as `get_html_attrs`
-        
+
         """
         kwargs['type'] = 'radio'
         kwargs['name'] = self.name
         html = []
         value = self.to_string(**kwargs)
         items = _items or self.items
-        
+
         for val, label in items:
             kwargs['value'] = val
             kwargs['checked'] = (str(val) == str(value))
             html_attrs = get_html_attrs(kwargs)
-            html.append(tmpl.format(attrs=html_attrs, label=label))
+            item_html = (tmpl
+                         .replace(u'{attrs}', html_attrs)
+                         .replace(u'{label}', label)
+                         .replace(u'{value}', to_unicode(val))
+                         )
+            html.append(item_html)
 
         return Markup('\n'.join(html))
 
 
 class MultiSelect(Field):
+
     """Like a ``:class:solution.Select``but allows to choose more than one
     option at a time.
 
     :param items:
-        Either: 
+        Either:
         - An list of tuples with the format `(value, label)`; or
         - A function that return a list of items in that format.
 
@@ -155,9 +172,10 @@ class MultiSelect(Field):
 
     """
 
-    def __init__(self, items, **kwargs):
+    def __init__(self, items, type=None, **kwargs):
         kwargs.setdefault('default', [])
         self._items = items
+        self.type = type
         super(MultiSelect, self).__init__(**kwargs)
 
     @property
@@ -182,9 +200,18 @@ class MultiSelect(Field):
         if self.str_value is None:
             return None
         accepted = [str(item[0]) for item in self]
-        py_value = [v for v in self.str_value if v in accepted]
+        py_value = [self._clean_value(v)
+                    for v in self.str_value if v in accepted]
         return py_value or None
 
+    def _clean_value(self, value):
+        if not self.type:
+            return value
+        try:
+            return self.type(value)
+        except (ValueError, TypeError):
+            return None
+
     def __call__(self, **kwargs):
         items = self.items
         if len(items) > 5:
@@ -193,11 +220,11 @@ class MultiSelect(Field):
 
     def as_select(self, _items=None, **kwargs):
         """Render the field as a `<select>` element.
-        
+
         :param **kwargs:
             Named paremeters used to generate the HTML attributes of each item.
             It follows the same rules as `get_html_attrs`
-        
+
         """
         kwargs['name'] = self.name
         if not self.optional:
@@ -232,12 +259,19 @@ class MultiSelect(Field):
         html = []
         values = self.to_string(**kwargs) or []
         items = _items or self.items
-        
+
         for val, label in items:
             kwargs['value'] = val
             kwargs['checked'] = (val in values or str(val) in values)
             html_attrs = get_html_attrs(kwargs)
-            html.append(tmpl.format(attrs=html_attrs, label=label))
+            item_html = (tmpl
+                         .replace(u'{attrs}', html_attrs)
+                         .replace(u'{label}', label)
+                         .replace(u'{value}', to_unicode(val))
+                         )
+            html.append(item_html)
 
         return Markup('\n'.join(html))
 
+    as_checks = as_checkboxes
+
